File

Struct File 

pub struct File { /* private fields */ }
A file on disk which stores, or can store, a JWT for authenticating with SpacetimeDB.

The file does not necessarily exist or store credentials. If the credentials have been stored previously, they can be accessed with File::load. New credentials can be saved to disk with File::save.

Implementations

Source

impl File

pub fn new(key: impl Into<String>) -> Self

Get a handle on a file which stores a SpacetimeDB [Identity] and its private access token.

This method does not create the file or check that it exists.

Distinct applications running as the same user on the same machine may share [Identity]/token pairs by supplying the same key. Users who desire distinct credentials for their application should supply a unique key per application.

No additional namespacing is provided to tie the stored token to a particular SpacetimeDB instance or cluster. Users who intend to connect to multiple instances or clusters should use a distinct key per cluster.

pub fn save(self, token: impl Into<String>) -> Result<(), CredentialFileError>

Store the provided token to disk in the file referred to by self.

Future calls to Self::load on a File with the same key can retrieve the token.

Expected usage is to call this from a [super::DbConnectionBuilder::on_connect] callback.

DbConnection::builder()
  .on_connect(|_ctx, _identity, token| {
      credentials::File::new("my_app").save(token).unwrap();
})
pub fn load(self) -> Result<Option<String>, CredentialFileError>

Load a saved token from disk in the file referred to by self, if they have previously been stored by Self::save.

Returns Err if I/O fails, None if credentials have not previously been stored, or Some if credentials are successfully loaded from disk. After unwrapping the Result, the returned Option can be passed to [super::DbConnectionBuilder::with_token].

DbConnection::builder()
  .with_token(credentials::File::new("my_app").load().unwrap())